@@ -405,7 +405,7 @@ FILE *current_output;
  */
 extern struct xcmd opcmds[];
 
-char *progname;
+char const *progname;
 
 #ifdef NO_MAIN_ALLOWED
 #ifndef BUILD_AS_LIB
